@@ -1,6 +1,9 @@
 describe.logit.gam<-function(){
 category <- "dichotomous"
 description  <- "Generalized Additive Model for Dichotomous Dependent Variables"
+authors <- c("Skyler J. Cranmer")
+year <- 2007
+
 package <-list(	name 	="mgcv",
 		version	="0.1"
 		)
@@ -11,5 +14,5 @@ parameters$pi<-list(equations=c(1,1),
 			expVar=TRUE
 			)
 			
-list(category=category,description=description,package=package,parameters=parameters)
+list(category = category, authors = authors, year = year,description=description,package=package,parameters=parameters)
 }
