@@ -1,6 +1,9 @@
 describe.gamma.net<-function(){
 category <- "bounded"
 description  <- "Social Network Gamma Regression for Continuous, Positive Dependent Variables"
+authors <- c("Skyler J. Cranmer")
+year <- 2007
+
 package <-list(	name 	="sna",
 		version	="1.4"
 		)
@@ -11,5 +14,5 @@ parameters$lambda<-list(equations=c(1,1),
 			expVar=TRUE
 			)
 			
-list(category=category,description=description,package=package,parameters=parameters)
+list(category = category, authors = authors, year = year,description=description,package=package,parameters=parameters)
 }
